@@ -6,7 +6,7 @@ module Config
   RUBY_VERSION == "1.8.6" or
     raise "ruby lib version (1.8.6) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/arm-openbsd4.4")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/arm-openbsd4.5")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
@@ -43,6 +43,7 @@ module Config
   CONFIG["libdir"] = "$(exec_prefix)/lib"
   CONFIG["localedir"] = "$(datarootdir)/locale"
   CONFIG["mandir"] = "$(DESTDIR)/usr/local/man"
+  CONFIG["DEFS"] = ""
   CONFIG["ECHO_C"] = ""
   CONFIG["ECHO_N"] = "-n"
   CONFIG["ECHO_T"] = ""
@@ -53,22 +54,22 @@ module Config
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
   CONFIG["TEENY"] = "6"
-  CONFIG["build"] = "arm-unknown-openbsd4.4"
+  CONFIG["build"] = "arm-unknown-openbsd4.5"
   CONFIG["build_cpu"] = "arm"
   CONFIG["build_vendor"] = "unknown"
-  CONFIG["build_os"] = "openbsd4.4"
-  CONFIG["host"] = "arm-unknown-openbsd4.4"
+  CONFIG["build_os"] = "openbsd4.5"
+  CONFIG["host"] = "arm-unknown-openbsd4.5"
   CONFIG["host_cpu"] = "arm"
   CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_os"] = "openbsd4.4"
-  CONFIG["target"] = "arm-unknown-openbsd4.4"
+  CONFIG["host_os"] = "openbsd4.5"
+  CONFIG["target"] = "arm-unknown-openbsd4.5"
   CONFIG["target_cpu"] = "arm"
   CONFIG["target_vendor"] = "unknown"
-  CONFIG["target_os"] = "openbsd4.4"
+  CONFIG["target_os"] = "openbsd4.5"
   CONFIG["CC"] = "cc"
   CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC"
   CONFIG["LDFLAGS"] = "-L.  -Wl,-E"
-  CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE"
+  CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE $(DEFS)"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPP"] = "cc -E"
   CONFIG["GREP"] = "/usr/bin/grep"
@@ -104,8 +105,8 @@ module Config
   CONFIG["DLEXT2"] = ""
   CONFIG["LIBEXT"] = "a"
   CONFIG["LINK_SO"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L'%1$-s'"
-  CONFIG["RPATHFLAG"] = " -Wl,-R'%1$-s'"
+  CONFIG["LIBPATHFLAG"] = " -L%1$-s"
+  CONFIG["RPATHFLAG"] = " -Wl,-R%1$-s"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
   CONFIG["TRY_LINK"] = ""
   CONFIG["STRIP"] = "strip"
@@ -139,10 +140,10 @@ module Config
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
   CONFIG["MAKEFILES"] = "Makefile"
-  CONFIG["arch"] = "arm-openbsd4.4"
-  CONFIG["sitearch"] = "arm-openbsd4.4"
+  CONFIG["arch"] = "arm-openbsd4.5"
+  CONFIG["sitearch"] = "arm-openbsd4.5"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.4' '--with-tk-include=/usr/local/include/tk8.4' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE' 'YACC=yacc'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE' 'YACC=yacc'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
