@@ -85,7 +85,9 @@
 #define HAVE_CRYPT 1
 #define HAVE_FLOCK 1
 #define HAVE_VSNPRINTF 1
+#define HAVE_ISNAN 1
 #define HAVE_FINITE 1
+#define HAVE_ISINF 1
 #define HAVE_HYPOT 1
 #define HAVE_ACOSH 1
 #define HAVE_ERF 1
@@ -98,6 +100,7 @@
 #define HAVE_FSYNC 1
 #define HAVE_GETCWD 1
 #define HAVE_TRUNCATE 1
+#define HAVE_FTRUNCATE 1
 #define HAVE_TIMES 1
 #define HAVE_UTIMES 1
 #define HAVE_FCNTL 1
@@ -138,9 +141,11 @@
 #define HAVE_FCHMOD 1
 #define HAVE_MKTIME 1
 #define HAVE_TIMEGM 1
+#define HAVE_GETTIMEOFDAY 1
 #define HAVE_COSH 1
 #define HAVE_SINH 1
 #define HAVE_TANH 1
+#define HAVE_ROUND 1
 #define HAVE_SETUID 1
 #define HAVE_SETGID 1
 #define HAVE_SETENV 1
@@ -148,6 +153,7 @@
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
+#define HAVE_TIMEZONE 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define GETPGRP_VOID 1
@@ -165,6 +171,6 @@
 #define RUBY_LIB "/usr/local/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.8"
-#define RUBY_PLATFORM "hppa-openbsd4.4"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/hppa-openbsd4.4"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/hppa-openbsd4.4"
+#define RUBY_PLATFORM "hppa-openbsd4.5"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/hppa-openbsd4.5"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/hppa-openbsd4.5"
