@@ -1,5 +1,5 @@
 =begin
-= $RCSfile: cipher.rb,v $ -- Ruby-space predefined Cipher subclasses
+= $RCSfile$ -- Ruby-space predefined Cipher subclasses
 
 = Info
   'OpenSSL for Ruby 2' project
@@ -11,7 +11,7 @@
   (See the file 'LICENCE'.)
 
 = Version
-  $Id: cipher.rb,v 1.1.2.1 2005/03/09 11:26:48 gotoyuzo Exp $
+  $Id: cipher.rb 11708 2007-02-12 23:01:19Z shyouhei $
 =end
 
 ##
@@ -20,19 +20,25 @@
 
 module OpenSSL
   module Cipher
-    %w(AES CAST5 BF DES IDEA RC2 RC4 RC5).each{|cipher|
-      eval(<<-EOD)
-        class #{cipher} < Cipher
-          def initialize(*args)
-            args = args.join('-')
-            if args.size == 0
-              super(\"#{cipher}\")
-            else
-              super(\"#{cipher}-#\{args\}\")
-            end
-          end
-        end
-      EOD
+    %w(AES CAST5 BF DES IDEA RC2 RC4 RC5).each{|name|
+      klass = Class.new(Cipher){
+        define_method(:initialize){|*args|
+          cipher_name = args.inject(name){|n, arg| "#{n}-#{arg}" }
+          super(cipher_name)
+        }
+      }
+      const_set(name, klass)
+    }
+
+    %w(128 192 256).each{|keylen|
+      klass = Class.new(Cipher){
+        define_method(:initialize){|mode|
+          mode ||= "CBC"
+          cipher_name = "AES-#{keylen}-#{mode}"
+          super(cipher_name)
+        }
+      }
+      const_set("AES#{keylen}", klass)
     }
 
     class Cipher
